# Contributing

All contributions are welcome. Choose an open issue that has been marked as `Help Needed`, and send a PR for it.

Also please follow the following guidelines:

1. Use PEP 8 code style
   - 120 characters line limit
   - double quotes are preferred
   - don't forget newline at the end of the file
2. Commit messages should be self explanatory. It should answer following questions:
   - Why is this change necessary?
   - How does it address the issue?
   - What side effects does this change have?
3. Your branch should have just the right number of commits not too many, not too few.
   - Logically relevant changes SHOULD get committed together.
   - Logically irrelevant changes SHOULD NOT get committed together.
